pub struct TestOrderBuilder { /* private fields */ }Expand description
Builder for creating test SignedOrder instances.
Implementations
Sourceimpl TestOrderBuilder
impl TestOrderBuilder
Sourcepub fn with_constants(self, constants: SignetSystemConstants) -> Self
pub fn with_constants(self, constants: SignetSystemConstants) -> Self
Use the provided system constants.
Sourcepub fn with_input(self, token: Address, amount: U256) -> Self
pub fn with_input(self, token: Address, amount: U256) -> Self
Append a new input to the collection of inputs.
Sourcepub fn with_output(
self,
token: Address,
amount: U256,
recipient: Address,
chain_id: u64,
) -> Self
pub fn with_output( self, token: Address, amount: U256, recipient: Address, chain_id: u64, ) -> Self
Append a new output to the collection of outputs.
Sourcepub fn with_nonce(self, nonce: u64) -> Self
pub fn with_nonce(self, nonce: u64) -> Self
Set the nonce.
Sourcepub async fn sign<S: Signer>(self, signer: &S) -> SignedOrder
pub async fn sign<S: Signer>(self, signer: &S) -> SignedOrder
Sign and build the order.