HostBlockSpec

Struct HostBlockSpec 

pub struct HostBlockSpec {
    pub constants: SignetSystemConstants,
    pub receipts: Vec<ReceiptEnvelope>,
    pub ru_block: Option<RuBlockSpec>,
    pub sidecar: Option<BlobTransactionSidecar>,
    pub ru_block_receipt: Option<ReceiptEnvelope>,
    pub block_number: AtomicU64,
    pub events: Vec<Events>,
}
A block spec for the host chain.

Typically this should be used as follows:

  1. Instantiate with a SignetSystemConstants object via Self::new.
  2. Add Signet events to the block with Self::enter, Self::enter_token Self::transact, and Self::fill.
  3. (optional) Add a RuBlockSpec with Self::submit_block.
  4. Convert to a Chain with Self::to_chain, or a NotificationSpec with Self::to_commit_notification_spec.

Fields

constants: SignetSystemConstants

The system constants for the block.

receipts: Vec<ReceiptEnvelope>

The Zenith-event receipts in the block.

ru_block: Option<RuBlockSpec>

The Ru block associated with this host block (if any).

sidecar: Option<BlobTransactionSidecar>

The sidecar associated with the Ru block (if any).

ru_block_receipt: Option<ReceiptEnvelope>

The receipt for the Ru block (if any).

block_number: AtomicU64

The block number. This will be overridden when making chains of blocks.

events: Vec<Events>

The events that were used to create this block.

Implementations

Source

impl HostBlockSpec

pub const fn new(constants: SignetSystemConstants) -> Self

Make a new block spec

pub const fn mainnet() -> Self

Make a new block spec with Mainnet constants.

pub const fn parmigiana() -> Self

Make a new block spec with Parmigiana constants.

pub const fn gouda() -> Self

Make a new block spec with Gouda constants.

pub const fn pecorino() -> Self

👎Deprecated:

Pecorino is being deprecated in favor of Parmigiana

Make a new block spec with Pecorino constants.

pub const fn test() -> Self

Make a new block spec with test constants.

pub fn with_block_number(self, block_number: u64) -> Self

Set the block number.

pub fn enter_token( self, recipient: Address, amount: usize, token: Address, ) -> Self

Add an enter to the host block.

pub fn ingnored_enter_token( self, recipient: Address, amount: u64, token: Address, ) -> Self

Add an ignored enter token to the host block

pub fn enter_tokens<'a, T>( self, enter_tokens: impl IntoIterator<Item = T>, ) -> Self
where T: Borrow<(Address, usize, Address)> + 'a,

Add an iter of enter tokens to the host block

pub fn enter(self, recipient: Address, amount: usize) -> Self

Add an enter to the host block.

pub fn ignored_enter(self, recipient: Address, amount: u64) -> Self

Add an enter to the host block that is ignored by the Ru chain because it has a mismatched RU chain ID.

pub fn enters<'a, T>(self, enters: impl IntoIterator<Item = T>) -> Self
where T: Borrow<(Address, usize)> + 'a,

Add several enters to the host block.

pub fn transact(self, t: Transact) -> Self

Add a transact to the host block

pub fn simple_transact( self, sender: Address, target: Address, data: impl AsRef<[u8]>, value: usize, ) -> Self

Add a simple transact to the host block.

pub fn fill(self, token: Address, recipient: Address, amount: u64) -> Self

Add a fill to the host block

pub fn ignored_fill( self, token: Address, recipient: Address, amount: u64, ) -> Self

Add a fill to the host block that is ignored by the Ru chain because it has a mismatched RU chain ID.

pub fn submit_block(self, ru_block: RuBlockSpec) -> Self

Add a block submitted to the host block

pub fn block_number(&self) -> u64

Get the block number

pub fn set_block_number(&self, block_number: u64)

Set the block number

pub fn header(&self) -> SignetHeaderV1

Make a header

pub fn sealed_block(&self) -> SealedBlock

Make a block

pub fn recovered_block(&self) -> RecoveredBlock

Make a block with senders.

pub fn execution_outcome(&self) -> ExecutionOutcome

Make an execution outcome

pub fn to_chain(&self) -> (Chain, Option<BlobTransactionSidecar>)

Make a chain

pub fn to_commit_notification_spec(&self) -> NotificationSpec

Make a commit notification spec

pub fn to_notification_with_sidecar(&self) -> NotificationWithSidecars

Make a reorg notification with sidecars

pub fn to_revert_notification_spec(&self) -> NotificationSpec

Make a revert notification spec

pub fn assert_conforms<C: Extractable>(&self, extracts: &Extracts<'_, C>)

Assert that the block conforms to the spec