pub struct NotificationSpec {
pub old: Vec<HostBlockSpec>,
pub new: Vec<HostBlockSpec>,
}Expand description
A notification spec.
Fields
old: Vec<HostBlockSpec>The old blocks.
new: Vec<HostBlockSpec>The new blocks.
Implementations
Sourceimpl NotificationSpec
impl NotificationSpec
Sourcepub fn commit_single_block(block: HostBlockSpec) -> Self
pub fn commit_single_block(block: HostBlockSpec) -> Self
Make a new notification spec from a single block
Sourcepub fn revert_single_block(block: HostBlockSpec) -> Self
pub fn revert_single_block(block: HostBlockSpec) -> Self
Make a new notification spec from a single block
Sourcepub fn commit(self, block: HostBlockSpec) -> Self
pub fn commit(self, block: HostBlockSpec) -> Self
Commit a block to the spec.
Sourcepub fn revert(self, block: HostBlockSpec) -> Self
pub fn revert(self, block: HostBlockSpec) -> Self
Add a block to revert to the spec.
Sourcepub fn to_exex_notification(&self) -> NotificationWithSidecars
pub fn to_exex_notification(&self) -> NotificationWithSidecars
Convert to an exex notification.