RuBlockSpec

Struct RuBlockSpec 

pub struct RuBlockSpec {
    pub constants: SignetSystemConstants,
    pub tx: Vec<Vec<u8>>,
    pub gas_limit: Option<u64>,
    pub reward_address: Option<Address>,
}
A block spec for the Ru chain.

Typically this should be used as follows:

  1. Instantiate with a SignetSystemConstants object via Self::new.
  2. Add transactions to the block with Self::add_tx.
  3. Optionally set the gas limit with Self::with_gas_limit.
  4. Optionally set the reward address with Self::with_reward_address.
  5. Add to a HostBlockSpec via HostBlockSpec::add_ru_block.

Fields

constants: SignetSystemConstants

The system constants for the block.

tx: Vec<Vec<u8>>

The transactions in the block.

gas_limit: Option<u64>

The gas limit for the block.

reward_address: Option<Address>

The reward address for the block.

Implementations

Source

impl RuBlockSpec

pub const fn new(constants: SignetSystemConstants) -> Self

Create a new empty RU block spec.

pub const fn mainnet() -> Self

Create a new empty RU block spec with the Mainnet constants.

pub const fn parmigiana() -> Self

Create a new empty RU block spec with the Parmigiana constants.

pub const fn gouda() -> Self

Create a new empty RU block spec with the Gouda constants.

pub const fn pecorino() -> Self

👎Deprecated:

Pecorino is being deprecated in favor of Parmigiana

Create a new empty RU block spec with the Pecorino constants.

pub const fn test() -> Self

Create a new empty RU block spec with the test constants.

pub const fn with_gas_limit(self, gas_limit: u64) -> Self

Builder method to set the gas limit.

pub const fn with_reward_address(self, reward_address: Address) -> Self

Builder method to set the reward address.

pub fn add_tx(&mut self, tx: &TxEnvelope)

Add a transaction to the block.

pub fn add_alloy_tx(&mut self, tx: &TxEnvelope)

Add an alloy transaction to the block

pub fn add_invalid_tx(&mut self, tx: impl Into<Bytes>)

Add an invalid transaction to the block.

pub fn tx(self, tx: &TxEnvelope) -> Self

Add a transaction to the block, returning self.

pub fn alloy_tx(self, tx: &TxEnvelope) -> Self

Add an alloy transaction to the block, returning self.

pub fn add_simple_send( &mut self, wallet: &PrivateKeySigner, to: Address, amount: U256, nonce: u64, ) -> TxEnvelope

Add a simple send to the block, returns the send added.

pub fn to_sidecar(&self) -> (B256, BlobTransactionSidecar)

Convert to a host sidecar.

pub fn to_block_submitted(&self) -> (BlockSubmitted, BlobTransactionSidecar)

Convert to a block submitted, along with the sidecar.

pub fn assert_conforms<C: Extractable>(&self, extracts: &Extracts<'_, C>)

Assert that extracted data conforms to the block spec.