pub struct HostBlockSpec {
pub constants: SignetSystemConstants,
pub receipts: Vec<ReceiptEnvelope>,
pub ru_block: Option<RuBlockSpec>,
pub sidecar: Option<BlobTransactionSidecar>,
pub ru_block_receipt: Option<ReceiptEnvelope>,
pub block_number: AtomicU64,
pub events: Vec<Events>,
}Expand description
A block spec for the host chain.
Typically this should be used as follows:
- Instantiate with a
SignetSystemConstantsobject viaSelf::new. - Add Signet events to the block with
Self::enter,Self::enter_tokenSelf::transact, andSelf::fill. - (optional) Add a
RuBlockSpecwithSelf::submit_block. - Convert to a
ChainwithSelf::to_chain, or aNotificationSpecwithSelf::to_commit_notification_spec.
Fields
constants: SignetSystemConstantsThe system constants for the block.
receipts: Vec<ReceiptEnvelope>The Zenith-event receipts in the block.
ru_block: Option<RuBlockSpec>The Ru block associated with this host block (if any).
sidecar: Option<BlobTransactionSidecar>The sidecar associated with the Ru block (if any).
ru_block_receipt: Option<ReceiptEnvelope>The receipt for the Ru block (if any).
block_number: AtomicU64The block number. This will be overridden when making chains of blocks.
events: Vec<Events>The events that were used to create this block.
Implementations
Sourceimpl HostBlockSpec
impl HostBlockSpec
Sourcepub const fn new(constants: SignetSystemConstants) -> Self
pub const fn new(constants: SignetSystemConstants) -> Self
Make a new block spec
Sourcepub const fn parmigiana() -> Self
pub const fn parmigiana() -> Self
Make a new block spec with Parmigiana constants.
Sourcepub const fn pecorino() -> Self
👎Deprecated: Pecorino is being deprecated in favor of Parmigiana
pub const fn pecorino() -> Self
Pecorino is being deprecated in favor of Parmigiana
Make a new block spec with Pecorino constants.
Sourcepub fn with_block_number(self, block_number: u64) -> Self
pub fn with_block_number(self, block_number: u64) -> Self
Set the block number.
Sourcepub fn enter_token(
self,
recipient: Address,
amount: usize,
token: Address,
) -> Self
pub fn enter_token( self, recipient: Address, amount: usize, token: Address, ) -> Self
Add an enter to the host block.
Sourcepub fn ingnored_enter_token(
self,
recipient: Address,
amount: u64,
token: Address,
) -> Self
pub fn ingnored_enter_token( self, recipient: Address, amount: u64, token: Address, ) -> Self
Add an ignored enter token to the host block
Sourcepub fn enter_tokens<'a, T>(
self,
enter_tokens: impl IntoIterator<Item = T>,
) -> Self
pub fn enter_tokens<'a, T>( self, enter_tokens: impl IntoIterator<Item = T>, ) -> Self
Add an iter of enter tokens to the host block
Sourcepub fn ignored_enter(self, recipient: Address, amount: u64) -> Self
pub fn ignored_enter(self, recipient: Address, amount: u64) -> Self
Add an enter to the host block that is ignored by the Ru chain because it has a mismatched RU chain ID.
Sourcepub fn enters<'a, T>(self, enters: impl IntoIterator<Item = T>) -> Self
pub fn enters<'a, T>(self, enters: impl IntoIterator<Item = T>) -> Self
Add several enters to the host block.
Sourcepub fn simple_transact(
self,
sender: Address,
target: Address,
data: impl AsRef<[u8]>,
value: usize,
) -> Self
pub fn simple_transact( self, sender: Address, target: Address, data: impl AsRef<[u8]>, value: usize, ) -> Self
Add a simple transact to the host block.
Sourcepub fn fill(self, token: Address, recipient: Address, amount: u64) -> Self
pub fn fill(self, token: Address, recipient: Address, amount: u64) -> Self
Add a fill to the host block
Sourcepub fn ignored_fill(
self,
token: Address,
recipient: Address,
amount: u64,
) -> Self
pub fn ignored_fill( self, token: Address, recipient: Address, amount: u64, ) -> Self
Add a fill to the host block that is ignored by the Ru chain because it has a mismatched RU chain ID.
Sourcepub fn submit_block(self, ru_block: RuBlockSpec) -> Self
pub fn submit_block(self, ru_block: RuBlockSpec) -> Self
Add a block submitted to the host block
Sourcepub fn block_number(&self) -> u64
pub fn block_number(&self) -> u64
Get the block number
Sourcepub fn set_block_number(&self, block_number: u64)
pub fn set_block_number(&self, block_number: u64)
Set the block number
Sourcepub fn header(&self) -> SignetHeaderV1
pub fn header(&self) -> SignetHeaderV1
Make a header
Sourcepub fn sealed_block(&self) -> SealedBlock
pub fn sealed_block(&self) -> SealedBlock
Make a block
Sourcepub fn recovered_block(&self) -> RecoveredBlock
pub fn recovered_block(&self) -> RecoveredBlock
Make a block with senders.
Sourcepub fn execution_outcome(&self) -> ExecutionOutcome
pub fn execution_outcome(&self) -> ExecutionOutcome
Make an execution outcome
Sourcepub fn to_chain(&self) -> (Chain, Option<BlobTransactionSidecar>)
pub fn to_chain(&self) -> (Chain, Option<BlobTransactionSidecar>)
Make a chain
Sourcepub fn to_commit_notification_spec(&self) -> NotificationSpec
pub fn to_commit_notification_spec(&self) -> NotificationSpec
Make a commit notification spec
Sourcepub fn to_notification_with_sidecar(&self) -> NotificationWithSidecars
pub fn to_notification_with_sidecar(&self) -> NotificationWithSidecars
Make a reorg notification with sidecars
Sourcepub fn to_revert_notification_spec(&self) -> NotificationSpec
pub fn to_revert_notification_spec(&self) -> NotificationSpec
Make a revert notification spec
Sourcepub fn assert_conforms<C: Extractable>(&self, extracts: &Extracts<'_, C>)
pub fn assert_conforms<C: Extractable>(&self, extracts: &Extracts<'_, C>)
Assert that the block conforms to the spec