pub struct RuBlockSpec {
pub constants: SignetSystemConstants,
pub tx: Vec<Vec<u8>>,
pub gas_limit: Option<u64>,
pub reward_address: Option<Address>,
}Expand description
A block spec for the Ru chain.
Typically this should be used as follows:
- Instantiate with a
SignetSystemConstantsobject viaSelf::new. - Add transactions to the block with
Self::add_tx. - Optionally set the gas limit with
Self::with_gas_limit. - Optionally set the reward address with
Self::with_reward_address. - Add to a
HostBlockSpecviaHostBlockSpec::add_ru_block.
Fields
constants: SignetSystemConstantsThe system constants for the block.
tx: Vec<Vec<u8>>The transactions in the block.
gas_limit: Option<u64>The gas limit for the block.
reward_address: Option<Address>The reward address for the block.
Implementations
Sourceimpl RuBlockSpec
impl RuBlockSpec
Sourcepub const fn new(constants: SignetSystemConstants) -> Self
pub const fn new(constants: SignetSystemConstants) -> Self
Create a new empty RU block spec.
Sourcepub const fn parmigiana() -> Self
pub const fn parmigiana() -> Self
Create a new empty RU block spec with the Parmigiana constants.
Sourcepub const fn pecorino() -> Self
👎Deprecated: Pecorino is being deprecated in favor of Parmigiana
pub const fn pecorino() -> Self
Pecorino is being deprecated in favor of Parmigiana
Create a new empty RU block spec with the Pecorino constants.
Sourcepub const fn with_gas_limit(self, gas_limit: u64) -> Self
pub const fn with_gas_limit(self, gas_limit: u64) -> Self
Builder method to set the gas limit.
Sourcepub const fn with_reward_address(self, reward_address: Address) -> Self
pub const fn with_reward_address(self, reward_address: Address) -> Self
Builder method to set the reward address.
Sourcepub fn add_tx(&mut self, tx: &TxEnvelope)
pub fn add_tx(&mut self, tx: &TxEnvelope)
Add a transaction to the block.
Sourcepub fn add_alloy_tx(&mut self, tx: &TxEnvelope)
pub fn add_alloy_tx(&mut self, tx: &TxEnvelope)
Add an alloy transaction to the block
Sourcepub fn add_invalid_tx(&mut self, tx: impl Into<Bytes>)
pub fn add_invalid_tx(&mut self, tx: impl Into<Bytes>)
Add an invalid transaction to the block.
Sourcepub fn tx(self, tx: &TxEnvelope) -> Self
pub fn tx(self, tx: &TxEnvelope) -> Self
Add a transaction to the block, returning self.
Sourcepub fn alloy_tx(self, tx: &TxEnvelope) -> Self
pub fn alloy_tx(self, tx: &TxEnvelope) -> Self
Add an alloy transaction to the block, returning self.
Sourcepub fn add_simple_send(
&mut self,
wallet: &PrivateKeySigner,
to: Address,
amount: U256,
nonce: u64,
) -> TxEnvelope
pub fn add_simple_send( &mut self, wallet: &PrivateKeySigner, to: Address, amount: U256, nonce: u64, ) -> TxEnvelope
Add a simple send to the block, returns the send added.
Sourcepub fn to_sidecar(&self) -> (B256, BlobTransactionSidecar)
pub fn to_sidecar(&self) -> (B256, BlobTransactionSidecar)
Convert to a host sidecar.
Sourcepub fn to_block_submitted(&self) -> (BlockSubmitted, BlobTransactionSidecar)
pub fn to_block_submitted(&self) -> (BlockSubmitted, BlobTransactionSidecar)
Convert to a block submitted, along with the sidecar.
Sourcepub fn assert_conforms<C: Extractable>(&self, extracts: &Extracts<'_, C>)
pub fn assert_conforms<C: Extractable>(&self, extracts: &Extracts<'_, C>)
Assert that extracted data conforms to the block spec.